Crate wasm_dom

Crate wasm_dom 

Re-exports

pub use crate::error::Error;
pub use crate::error::Result;
pub use js_sys;
pub use wasm_bindgen;

Modules

Reflect
animation
correct
error
event
existing

Structs

Document
The Document class.
JsValue
Representation of an object owned by JS.
Location
The Location class.
Window
The Window class.

Traits

JsCast
A trait for dynamic checked and unchecked casting between JS types.
UnwrapThrowExt
An extension trait for Option<T> and Result<T, E> for unwrapping the T value, or throwing a JS error if it is not available.

Functions

body
document
document_element
elements
get_element_by_id
location
select_all_elements
select_all_elements_from
select_element
select_element_cast
select_element_from
set_timeout
setTimeout(func, delay_ms) for a one-shot callback.
window